# Review data structure for Review Graph Mining
[![GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/copyleft/gpl.html)
[![Build Status](https://travis-ci.org/rgmining/review.svg?branch=master)](https://travis-ci.org/rgmining/review)
[![wercker status](https://app.wercker.com/status/afc19091fbf86b8e5888486c638ac05a/s/master "wercker status")](https://app.wercker.com/project/byKey/afc19091fbf86b8e5888486c638ac05a)[![Code Climate](https://codeclimate.com/github/rgmining/review/badges/gpa.svg)](https://codeclimate.com/github/rgmining/review)
[![Release](https://img.shields.io/badge/release-0.9.0-brightgreen.svg)](https://github.com/rgmining/review/releases/tag/v0.9.0)

This package defines a data structure of review data. We assume review data
consist of reviews and summaries. A review is a set of information a user posts
to a product. On the other hand, a summary is computed from a set of reviews.

This package defines two types of reviews and those summaries; scalar review and
vector review.

See [documents](https://rgmining.github.io/review/) for more information.


## License
This software is released under The GNU General Public License Version 3,
see [COPYING](COPYING) for more detail.
